# -*- coding: utf-8 -*-
# (c) 2012 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com

from django.test import TestCase
from django.core.urlresolvers import reverse
from views import raise_exception
from raiseexception import DeliberateException


class RaiseExceptionViewTests(TestCase):
    def test_view_raises_exception(self):
        self.assertRaises(
            DeliberateException,
            raise_exception,
            request=None)


class RaiseExceptionUrlTests(TestCase):
    def test_url_raises_exception(self):
        self.assertRaises(
            DeliberateException,
            self._call_raise_exception_view)

    def _call_raise_exception_view(self):
        self.client.get(reverse('raise-exception'))



# -*- coding: utf-8 -*-
# (c) 2012 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com

from django.conf.urls.defaults import patterns, url


urlpatterns = patterns('raiseexception.views',
    url(r'^raise-exception$', 'raise_exception', name='raise-exception'),
)



# -*- coding: utf-8 -*-
# (c) 2012 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com


__version__ = '1.0.0'


class DeliberateException(Exception):
    """Exception that is deliberately raised to check that error logging is
    working."""

    def __init__(self, *args, **kwargs):
        super(DeliberateException, self).__init__(*args, **kwargs)



# -*- coding: utf-8 -*-
# (c) 2012 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com

from raiseexception import DeliberateException


def raise_exception(request):
    """
    Always throws an exception - useful for checking that exception logging is
    working
    """
    raise DeliberateException()
